@@ -6,6 +6,9 @@ package org.torproject.descriptor.impl;
 import org.torproject.descriptor.Descriptor;
 import org.torproject.descriptor.DescriptorParseException;
 
+import org.apache.commons.codec.binary.Base64;
+import org.apache.commons.codec.binary.Hex;
+
 import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.InputStreamReader;
@@ -19,8 +22,6 @@ import java.util.Map;
 import java.util.Scanner;
 import java.util.Set;
 
-import javax.xml.bind.DatatypeConverter;
-
 public abstract class DescriptorImpl implements Descriptor {
 
   public static final String NL = "\n";
@@ -59,7 +60,7 @@ public abstract class DescriptorImpl implements Descriptor {
   }
 
   /**
-   * Returns a <emph>copy</emph> of the full raw descriptor bytes.
+   * Returns a <em>copy</em> of the full raw descriptor bytes.
    *
    * <p>If possible, subclasses should avoid retrieving raw descriptor bytes and
    * converting them to a String themselves and instead rely on
@@ -73,8 +74,8 @@ public abstract class DescriptorImpl implements Descriptor {
   }
 
   /**
-   * Returns a <emph>copy</emph> of raw descriptor bytes starting at
-   * <code>offset</code> and containing <code>length</code> bytes.
+   * Returns a <em>copy</em> of raw descriptor bytes starting at
+   * {@code offset} and containing {@code length} bytes.
    *
    * <p>If possible, subclasses should avoid retrieving raw descriptor bytes and
    * converting them to a String themselves and instead rely on
@@ -108,7 +109,7 @@ public abstract class DescriptorImpl implements Descriptor {
 
   /**
    * Returns a new {@link Scanner} for parsing the raw descriptor starting at
-   * byte <code>offset</code> containing <code>length</code> bytes using UTF-8
+   * byte {@code offset} containing {@code length} bytes using UTF-8
    * as charset.
    *
    * @param offset The index of the first byte to parse.
@@ -122,7 +123,7 @@ public abstract class DescriptorImpl implements Descriptor {
 
   /**
    * Returns the index within the raw descriptor of the first occurrence of the
-   * given <code>key</code>, or <code>-1</code> if the key is not contained.
+   * given {@code key}, or {@code -1} if the key is not contained.
    *
    * @param key Key to search for.
    * @return Index of the first occurrence, or -1.
@@ -147,8 +148,8 @@ public abstract class DescriptorImpl implements Descriptor {
 
   /**
    * Returns a list of two-element arrays containing offsets and lengths of
-   * descriptors starting with the given <code>key</code> in the raw descriptor
-   * starting at byte <code>offset</code> containing <code>length</code> bytes.
+   * descriptors starting with the given {@code key} in the raw descriptor
+   * starting at byte {@code offset} containing {@code length} bytes.
    *
    * @param key Key to search for.
    * @param offset The index of the first byte to split.
@@ -188,7 +189,7 @@ public abstract class DescriptorImpl implements Descriptor {
 
   @Override
   public List<String> getUnrecognizedLines() {
-    return this.unrecognizedLines == null ? new ArrayList<String>()
+    return this.unrecognizedLines == null ? new ArrayList<>()
         : new ArrayList<>(this.unrecognizedLines);
   }
 
@@ -278,11 +279,7 @@ public abstract class DescriptorImpl implements Descriptor {
           this.firstKey = key;
         }
         lastKey = key;
-        if (parsedKeys.containsKey(key)) {
-          parsedKeys.put(key, parsedKeys.get(key) + 1);
-        } else {
-          parsedKeys.put(key, 1);
-        }
+        parsedKeys.put(key, parsedKeys.getOrDefault(key, 0) + 1);
       }
     }
   }
@@ -306,10 +303,7 @@ public abstract class DescriptorImpl implements Descriptor {
   protected void checkExactlyOnceKeys(Set<Key> keys)
       throws DescriptorParseException {
     for (Key key : keys) {
-      int contained = 0;
-      if (this.parsedKeys.containsKey(key)) {
-        contained = this.parsedKeys.get(key);
-      }
+      int contained = this.parsedKeys.getOrDefault(key, 0);
       if (contained != 1) {
         throw new DescriptorParseException("Keyword '" + key.keyword + "' is "
             + "contained " + contained + " times, but must be contained "
@@ -331,10 +325,10 @@ public abstract class DescriptorImpl implements Descriptor {
   protected void checkAtMostOnceKeys(Set<Key> keys)
       throws DescriptorParseException {
     for (Key key : keys) {
-      if (this.parsedKeys.containsKey(key)
-          && this.parsedKeys.get(key) > 1) {
+      int contained = this.parsedKeys.getOrDefault(key, 0);
+      if (contained > 1) {
         throw new DescriptorParseException("Keyword '" + key.keyword + "' is "
-            + "contained " + this.parsedKeys.get(key) + " times, "
+            + "contained " + contained + " times, "
             + "but must be contained at most once.");
       }
     }
@@ -353,11 +347,7 @@ public abstract class DescriptorImpl implements Descriptor {
   }
 
   protected int getKeyCount(Key key) {
-    if (!this.parsedKeys.containsKey(key)) {
-      return 0;
-    } else {
-      return this.parsedKeys.get(key);
-    }
+    return this.parsedKeys.getOrDefault(key, 0);
   }
 
   protected void clearParsedKeys() {
@@ -383,7 +373,7 @@ public abstract class DescriptorImpl implements Descriptor {
         end = ascii.indexOf(endToken) + endToken.length();
       }
       if (start >= 0 && end >= 0 && end > start) {
-        this.digestSha1Hex = DatatypeConverter.printHexBinary(
+        this.digestSha1Hex = Hex.encodeHexString(
             messageDigest("SHA-1", start, end)).toLowerCase();
       }
     }
@@ -426,7 +416,7 @@ public abstract class DescriptorImpl implements Descriptor {
         end = ascii.indexOf(endToken) + endToken.length();
       }
       if (start >= 0 && end >= 0 && end > start) {
-        this.digestSha256Base64 = DatatypeConverter.printBase64Binary(
+        this.digestSha256Base64 = Base64.encodeBase64String(
             messageDigest("SHA-256", start, end)).replaceAll("=", "");
       }
     }
