@@ -12,7 +12,6 @@ import org.torproject.descriptor.NetworkStatusEntry;
 import java.util.ArrayList;
 import java.util.BitSet;
 import java.util.EnumSet;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
@@ -48,13 +47,19 @@ public class NetworkStatusEntryImpl implements NetworkStatusEntry {
     return lines;
   }
 
+  private Map<String, Integer> flagIndexes;
+
+  private Map<Integer, String> flagStrings;
+
   protected NetworkStatusEntryImpl(DescriptorImpl parent, int offset,
-      int length, boolean microdescConsensus)
-      throws DescriptorParseException {
+      int length, boolean microdescConsensus, Map<String, Integer> flagIndexes,
+      Map<Integer, String> flagStrings) throws DescriptorParseException {
     this.parent = parent;
     this.offset = offset;
     this.length = length;
     this.microdescConsensus = microdescConsensus;
+    this.flagIndexes = flagIndexes;
+    this.flagStrings = flagStrings;
     this.parseStatusEntryBytes();
     this.clearAtMostOnceKeys();
   }
@@ -77,7 +82,7 @@ public class NetworkStatusEntryImpl implements NetworkStatusEntry {
      * this.parent.length as bounds, which is not what we want! */
     Scanner scanner = this.parent.newScanner(this.offset, this.length)
         .useDelimiter(NL);
-    String line = null;
+    String line;
     if (!scanner.hasNext() || !(line = scanner.next()).startsWith("r ")) {
       throw new DescriptorParseException("Status entry must start with "
           + "an r line.");
@@ -95,10 +100,10 @@ public class NetworkStatusEntryImpl implements NetworkStatusEntry {
           this.parseALine(line, parts);
           break;
         case S:
-          this.parseSLine(line, parts);
+          this.parseSLine(parts);
           break;
         case V:
-          this.parseVLine(line, parts);
+          this.parseVLine(line);
           break;
         case PR:
           this.parsePrLine(line, parts);
@@ -160,26 +165,22 @@ public class NetworkStatusEntryImpl implements NetworkStatusEntry {
     this.orAddresses.add(parts[1]);
   }
 
-  private static Map<String, Integer> flagIndexes = new HashMap<>();
-
-  private static Map<Integer, String> flagStrings = new HashMap<>();
-
-  private void parseSLine(String line, String[] parts)
+  private void parseSLine(String[] parts)
       throws DescriptorParseException {
     this.parsedAtMostOnceKey(Key.S);
-    BitSet flags = new BitSet(flagIndexes.size());
+    BitSet flags = new BitSet(this.flagIndexes.size());
     for (int i = 1; i < parts.length; i++) {
       String flag = parts[i];
-      if (!flagIndexes.containsKey(flag)) {
-        flagStrings.put(flagIndexes.size(), flag);
-        flagIndexes.put(flag, flagIndexes.size());
+      if (!this.flagIndexes.containsKey(flag)) {
+        this.flagStrings.put(this.flagIndexes.size(), flag);
+        this.flagIndexes.put(flag, this.flagIndexes.size());
       }
-      flags.set(flagIndexes.get(flag));
+      flags.set(this.flagIndexes.get(flag));
     }
     this.flags = flags;
   }
 
-  private void parseVLine(String line, String[] parts)
+  private void parseVLine(String line)
       throws DescriptorParseException {
     this.parsedAtMostOnceKey(Key.V);
     String noOptLine = line;
@@ -217,9 +218,7 @@ public class NetworkStatusEntryImpl implements NetworkStatusEntry {
     if (pairs.containsKey("Unmeasured")) {
       this.unmeasured = pairs.remove("Unmeasured") == 1L;
     }
-    if (!pairs.isEmpty()) {
-      /* Ignore unknown key-value pair. */
-    }
+    /* Ignore unknown key-value pair. */
   }
 
   private void parsePLine(String line, String[] parts)
@@ -235,8 +234,8 @@ public class NetworkStatusEntryImpl implements NetworkStatusEntry {
           this.defaultPolicy = parts[1];
           this.portList = parts[2];
           String[] ports = parts[2].split(",", -1);
-          for (int i = 0; i < ports.length; i++) {
-            if (ports[i].length() < 1) {
+          for (String port : ports) {
+            if (port.length() < 1) {
               isValid = false;
               break;
             }
@@ -355,7 +354,7 @@ public class NetworkStatusEntryImpl implements NetworkStatusEntry {
     if (this.flags != null) {
       for (int i = this.flags.nextSetBit(0); i >= 0;
           i = this.flags.nextSetBit(i + 1)) {
-        result.add(flagStrings.get(i));
+        result.add(this.flagStrings.get(i));
       }
     }
     return result;
